<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=tr
// ** ne pas modifier le fichier **

return [

	// A
	'activer_plugin' => 'Plugin’i etkinleştir',
	'affichage' => 'Gösterim',
	'aide_non_disponible' => 'Çevrimiçi yardımın bu kısmı henüz bu dile çevrilmemiş.',
	'auteur' => 'Yazar :',
	'avis_acces_interdit' => 'Erişim yasak.',
	'avis_article_modifie' => 'Dikkat, @nom_auteur_modif@ bu metin üzerinde @date_diff@ dakika önce çalıştı',
	'avis_aucun_resultat' => 'Hiç sonuç yok.',
	'avis_chemin_invalide_1' => 'Seçtiğiniz yol',
	'avis_chemin_invalide_2' => 'geçersiz gözüküyor. Verdiğiniz bilgileri kontrol etmek için lütfen bir önceki sayfaya dönün.',
	'avis_connexion_echec_1' => 'SQL veri tabanına bağlantı başarısız.',
	'avis_connexion_echec_2' => 'Bir önceki sayfaya geri dönüp verdiğiniz bilgileri kontrol edin.',
	'avis_connexion_echec_3' => '<b>Not:</b> Bir çok sunucuda, SQL veritabanı kullanabilmek için aktive edilmesini <b>talep etmeniz</b> gerekir. Eğer bağlanamıyorsanız bunu talep edip etmediğinizi kontrol edin.',
	'avis_connexion_ldap_echec_1' => 'LDAP sunucusuna bağlantı başarısız.',
	'avis_connexion_ldap_echec_2' => 'Bir önceki sayfaya dönüp verdiğiniz bilgileri kontrol edin.',
	'avis_connexion_ldap_echec_3' => 'Buna alternatif olarak, kullanıcı ithal etmek için LDAP sunucusunu kullanmayın.', # MODIF
	'avis_deplacement_rubrique' => 'Dikkat ! Bu bölüm @contient_breves@ kısa haber @scb@ içeriyor: eğer yerini değiştiriyorsanız (taşıyorsanız) lütfen bu onay kutucuğunu işaretleyin.',
	'avis_erreur_connexion_mysql' => 'SQL bağlantısı hatası',
	'avis_espace_interdit' => '<b>Yasak alan</b> <div>SPIP zaten kurulu.</div>',
	'avis_lecture_noms_bases_1' => 'Kurulum yazılımı mevcut veritabanlarının isimlerini okuyamadı.',
	'avis_lecture_noms_bases_2' => 'Ya mevcut veritabanı yok, ya da veritabanlarının listesini almaya yarayan komut güvenlik nedeniyle kullanıma kapatılmış (bir çok barındırma şirketinde alınan bir tedbir).',
	'avis_lecture_noms_bases_3' => 'İkinci durumda, büyük olasılıkla kullanıcı isminizle aynı isimde bir veritabanı var :',
	'avis_non_acces_page' => 'Bu sayfaya erişiminiz yok.',
	'avis_operation_echec' => 'İşlem başarısız.',
	'avis_operation_impossible' => 'Olanaksız işlem',
	'avis_suppression_base' => 'DİKKAT, verileri silme işlemi geri alınamaz',

	// B
	'bouton_acces_ldap' => 'LDAP’a erişim ekle >>',
	'bouton_ajouter' => 'Ekle',
	'bouton_annuler' => 'İptal',
	'bouton_demande_publication' => 'Bu makalenin yayınlanmasını iste',
	'bouton_desactive_tout' => 'Hepsinin etkinliğini durdur ',
	'bouton_desinstaller' => 'Sil',
	'bouton_effacer_tout' => 'HEPSİNİ sil',
	'bouton_envoyer_message' => 'İletinin son hali : yolla',
	'bouton_mettre_a_jour' => 'Güncelle',
	'bouton_modifier' => 'Değiştir',
	'bouton_radio_afficher' => 'Göster ',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Bağlı yazarlar listesinde görün', # MODIF
	'bouton_radio_envoi_annonces_adresse' => 'Duyuruları bu adrese yolla :',
	'bouton_radio_envoi_liste_nouveautes' => 'Yenilikler listesini yolla ',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Yazarlar listesinde görünme', # MODIF
	'bouton_radio_non_envoi_annonces_editoriales' => 'Editör duyurularını gönderme',
	'bouton_redirection' => 'YÖNLENDİRME',
	'bouton_relancer_installation' => 'Kurulumu tekrar başlat',
	'bouton_suivant' => 'Bir sonraki ',
	'bouton_tenter_recuperation' => 'Onarmayı dene',
	'bouton_test_proxy' => 'Vekili dene',
	'bouton_vider_cache' => 'Önbelleği boşalt',

	// C
	'cache_modifiable_webmestre' => 'Bu parametreler site yöneticisi tarafından değiştirilebilir.', # MODIF
	'calendrier_synchro' => 'iCal uyumlu bir günlük uygulama yazılımı kullanıyorsanız onu bu sitedeki bilgilerle eşzamanlaştırabilirsiniz. ',
	'config_activer_champs' => 'Şu alanları aktive et',
	'config_choix_base_sup' => 'Bu sunucuda bir veri tabanı belirt',
	'config_erreur_base_sup' => 'SPIP erişilebilir veri tabanıları listesine erişemiyor',
	'config_info_base_sup' => 'SPIP üzerinden, SQL veya bir başka sunucu ile sorgulayacağınız başka veri tabanları varsa, aşağıdaki form bunları tanımlamanızı sağlar. Bazı alanları boş bırakırsanız ana veri tabanına bağlanmak için kullanılan bağlantı tanımlayıcıları kullanılacaktır.',
	'config_info_base_sup_disponibles' => 'Şu anda sorgulanabilir ek veri tabanları:',
	'config_info_enregistree' => 'Yeni konfigürasyon kaydedildi',
	'config_info_logos' => 'Sitenin her elemanı « üzerinden geçiş logosu da dahil olmak üzere » bir logoya sahip olabilir ',
	'config_info_logos_utiliser' => 'Logoları kullan',
	'config_info_logos_utiliser_non' => 'Logoları kullanma',
	'config_info_logos_utiliser_survol' => 'Üzerinden geçiş logolarını kullan',
	'config_info_logos_utiliser_survol_non' => 'Üzerinden geçiş logolarını kullanma',
	'config_info_redirection' => 'Bu seçeneği aktive ederek SPIP dışında veya başka sitelerde yayınlanmış basit makale referansları içeren sanal makaleler oluşturabilirsiniz.',
	'config_redirection' => 'Sanal makaleler',
	'config_titre_base_sup' => 'Ek bir veri tabanının tanımlanması',
	'config_titre_base_sup_choix' => 'Ek bir veri tabanı seçiniz',
	'connexion_ldap' => 'Bağlantı :',

	// D
	'date_mot_heures' => 'saat ',

	// E
	'email' => 'e-posta',
	'email_2' => 'e-posta :',
	'entree_adresse_annuaire' => 'Rehber adresi',
	'entree_adresse_email' => 'E-posta adresiniz',
	'entree_base_donnee_1' => 'Veritabanı adresi',
	'entree_base_donnee_2' => '(Bu adres çoğunlukla site adresinize karşı düşer, bazen «localhost» ifadesine karşı düşer, bazen tamamen boş bırakılır.)',
	'entree_biographie' => 'Bir kaç sözcükle kısa biyografi.',
	'entree_chemin_acces' => 'Erişim yolunu <b>giriniz</b> :',
	'entree_cle_pgp' => 'PGP anahtarınız',
	'entree_contenu_rubrique' => '(Bir kaç sözcükle bölüm içeriği.)',
	'entree_identifiants_connexion' => 'Bağlantı tanımlayıcılarınız...',
	'entree_informations_connexion_ldap' => 'Lütfen bu forma LDAP rehberine bağlantı için kullandığınız bilgileri giriniz. Bu bilgiler size sistem ya da ağ yöneticisi tarafından verilebilir.', # MODIF
	'entree_infos_perso' => 'Kimsiniz ?',
	'entree_interieur_rubrique' => 'Bölüm içerisinde :',
	'entree_liens_sites' => '<b>Hipermetin bağı</b> (atıflar, ziyaret edilecek site...)',
	'entree_login' => 'Kullanıcı isminiz',
	'entree_login_connexion_1' => 'Bağlantı için kullanıcı ismi',
	'entree_login_connexion_2' => '(Bazen FTP’ye bağlandığınız kullanıcı isminizdir bazen boş bırakılır) ',
	'entree_mot_passe' => 'Şifreniz',
	'entree_mot_passe_1' => 'Bağlantı şifreniz',
	'entree_mot_passe_2' => '(Bazen FTP şifrenize karşı düşer; bazen boş bırakılır)',
	'entree_nom_fichier' => 'Lütfen dosya ismini giriniz  @texte_compresse@:',
	'entree_nom_pseudo' => 'Adınız ya da takma adınız ',
	'entree_nom_pseudo_1' => '(Adınız ya da takma adınız) ',
	'entree_nom_site' => 'Sitenizin adı ',
	'entree_nouveau_passe' => 'Yeni şifre',
	'entree_passe_ldap' => 'Şifre',
	'entree_port_annuaire' => 'Rehberin kapı numarası',
	'entree_signature' => 'İmza',
	'entree_titre_obligatoire' => '<b>Başlık</b>  [Zorunlu]',
	'entree_url' => 'Sitenizin adresi (URL)',
	'erreur_plugin_desinstalation_echouee' => 'Eklenti kaldırma başarısız oldu. Ancak bunu devre dışı bırakabilirsiniz.', # RELIRE
	'erreur_plugin_fichier_absent' => 'Dosya eksik',
	'erreur_plugin_fichier_def_absent' => 'Tanımlama dosyası eksik',
	'erreur_plugin_nom_fonction_interdit' => 'Yasaklanmış işlev ismi',
	'erreur_plugin_nom_manquant' => 'Plugin ismi eksik',
	'erreur_plugin_prefix_manquant' => 'Plugin isimlendirme alanı tanımlanmamış',
	'erreur_plugin_tag_plugin_absent' => 'Tanımlama dosyasında &lt;plugin&gt; eksik',
	'erreur_plugin_version_manquant' => 'Plugin’in uyarlaması eksik',

	// I
	'ical_info1' => 'Bu sayfa bu sitenin yaşamı ile temas halinde kalmak için bir kaç yöntem sunmaktadır. ',
	'ical_info2' => 'Bu teknikler hakkında daha ayrıntılı bilgi için,  <a href="@spipnet@">SPIP dokümanlarına</a> bakmaktan çekinmeyiniz.',
	'ical_info_calendrier' => 'Kullanımınıza iki takvim sunulmuştur. Birincisi yayınlanmış tüm makaleleri duyuran bir site planıdır. İkincisi ise editör ilanları ile son olarak aldığınız özel iletilerinizi içerir : kişisel bir anahtar ile size ayrılmıştır ve buradaki bilgileri şifrenizi yenileyerek her an  değiştirebilirsiniz.',
	'ical_methode_http' => 'Yükleme',
	'ical_methode_webcal' => 'Eşzamanlaştırma (webcal://)',
	'ical_texte_prive' => 'Tamamen kişisel kullanıma ayrılmış bu takvim size bu sitenin özel editör etkinlikleri hakkında bilgi verir (kişisel işler ve randevular, önerilen makaleler ve haberler...).',
	'ical_texte_public' => 'Bu takvim bu sitenin kamu etkinliğini izlemenizi sağlar (yayınlanan makeleler ve haberler).',
	'ical_texte_rss' => 'Bu sitenin yeniliklerini herhangi bir XML/RSS (Rich Site Summary) formatındaki dosya okuyucusunda paylaşabilirsiniz. SPIP’e uyumlu değiş-tokuş formatı kullanan (paylaşımlı)  başka sitelerde yayınlanan yenilikleri okuma olanağı veren de bu formattır.',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'E-posta listesi',
	'ical_titre_rss' => 'Paylaşım dosyaları',
	'icone_accueil' => 'Giriş', # RELIRE
	'icone_activer_cookie' => 'Yazışma çerezini etkinleştir',
	'icone_admin_plugin' => 'Plugin’lerin yönetimi',
	'icone_administration' => 'Bakım işlemleri', # RELIRE
	'icone_afficher_auteurs' => 'Yazarları göster',
	'icone_afficher_visiteurs' => 'Ziyaretçileri görüntüle',
	'icone_arret_discussion' => 'Artık bu sohbete katılma',
	'icone_calendrier' => 'Takvim',
	'icone_configuration' => 'Ayarlar', # RELIRE
	'icone_creer_auteur' => 'Yeni bir yazar oluştur ve bu makaleye bağla',
	'icone_creer_mot_cle' => 'Yeni bir anahtar sözcük yarat ve bu makaleye bağla',
	'icone_creer_rubrique_2' => 'Yeni bir bölüm oluştur',
	'icone_modifier_article' => 'Bu makaleyi değiştir',
	'icone_modifier_rubrique' => 'Bu bölümü değiştir',
	'icone_publication' => 'Yayın', # RELIRE
	'icone_relancer_signataire' => 'İmzalayanı tekrar başlat',
	'icone_retour' => 'Geri dön',
	'icone_retour_article' => 'Makaleye geri dön',
	'icone_suivi_publication' => 'Yayın izleme', # RELIRE
	'icone_supprimer_cookie' => 'Yazışma çerezini sil',
	'icone_supprimer_rubrique' => 'Bu bölümü sil',
	'icone_supprimer_signature' => 'Bu imzayı sil',
	'icone_valider_signature' => 'Bu imzayı onayla',
	'image_administrer_rubrique' => 'Bu bölümü yönetebilirsiniz',
	'impossible_modifier_login_auteur' => 'Impossible de modifier le login.', # MODIF
	'impossible_modifier_pass_auteur' => 'Impossible de modifier le mot de passe.', # MODIF
	'info_1_article' => '1 makale',
	'info_activer_cookie' => 'Bir <b>yazışma kurabiyesi</b> çalıştırabilirsiniz,
 bu sizin kolayca kamu sitesinden özel siteye geçmenizi sağlar.',
	'info_admin_etre_webmestre' => 'Kendime webmaster yetkileri ver', # RELIRE
	'info_admin_statuer_webmestre' => 'Bu yönetici’ne webmaster yetkileri ver', # MODIF
	'info_administrateur' => 'Yönetici', # MODIF
	'info_administrateur_1' => 'Yönetici', # MODIF
	'info_administrateur_2' => 'sitenindir (<i>dikkatli kullanınız</i>)',
	'info_administrateur_site_01' => 'Eğer site yöneticisiyseniz, lütfen', # MODIF
	'info_administrateur_site_02' => 'bu bağlantıya tıklayınız',
	'info_administrateurs' => 'Yöneticiler', # MODIF
	'info_administrer_rubrique' => 'Bu bölümü yönetebilirsiniz',
	'info_adresse' => 'şu adresteki :',
	'info_adresse_url' => 'Kamusal sitenin adresi (URL) ',
	'info_aide_en_ligne' => 'SPIP çevrimiçi yardım',
	'info_ajout_image' => 'Bir makalenin eki olarak resim eklediğinizde,
               SPIP sizin için otomatik olarak eklenen resimlerin ikonlarını (minyatürlerini) 
yaratabilir. Bu da otomatik olarak bir galeri
               ya da bir portföy oluşturmaya yarar.',
	'info_ajouter_rubrique' => 'Yönetecek başka bir bölüm ekle:',
	'info_annonce_nouveautes' => 'Yenilik duyurusu',
	'info_article' => 'makale ',
	'info_article_2' => 'makale',
	'info_article_a_paraitre' => 'Yayınlanacak ileri tarihli makaleler',
	'info_articles_02' => 'makale',
	'info_articles_2' => 'Makaleler',
	'info_articles_auteur' => 'Bu yazarın makaleleri',
	'info_articles_trouves' => 'Bulunan makaleler',
	'info_attente_validation' => 'Onay bekleyen makaleleriniz',
	'info_aujourdhui' => 'Bugün :',
	'info_auteur_gere_rubriques' => 'Bu yazar aşağıdaki bölümleri yönetir :', # RELIRE
	'info_auteur_gere_toutes_rubriques' => 'Bu yazar <b>bütün bölümler</b> yönetir', # RELIRE
	'info_auteur_gere_toutes_rubriques_2' => '<b>Bütün bölümler</b> yönetiyorum', # RELIRE
	'info_auteurs' => 'Yazarlar',
	'info_auteurs_par_tri' => 'yazarlar@partri@',
	'info_auteurs_trouves' => 'Bulunan yazarlar',
	'info_authentification_externe' => 'Dışarıdan tasdik',
	'info_avertissement' => 'Uyarı',
	'info_barre_outils' => 'alet çubuğuyla birlikte mi ?',
	'info_base_installee' => 'Veritabanınızın yapısı kuruldu.',
	'info_bio' => 'Biyografi', # RELIRE
	'info_cache_desactive' => 'Önbellek, geçici olarak devre dışı bırakıldı.', # RELIRE
	'info_chapeau' => 'Giriş',
	'info_chapeau_2' => 'Giriş :',
	'info_chemin_acces_1' => 'Seçenekler : <b>Rehbere erişim yolu</b>',
	'info_chemin_acces_2' => 'Artık dizindeki bilgilere erişim yolunu düzenlemeniz gerekiyor. Bu bilgi dizinde bulundurulan kullanıcı profillerini okumak için şarttır. ', # MODIF
	'info_chemin_acces_annuaire' => 'Seçenekler : <b>Rehbere erişim yolu',
	'info_choix_base' => 'Üçüncü aşama :',
	'info_classement_1' => '@liste@’den     inci',
	'info_classement_2' => '@liste@’den     inci',
	'info_code_acces' => 'Kendi erişim şifrelerinizi unutmayınız !',
	'info_config_suivi' => 'Eğer bu adres bir gönderi listesi (mailing-list)’ne karşı düşüyorsa, aşağıya site katılımcılarının hangi adrese kaydolabileceklerini yazabilirsiniz. Bu adres URL (örneğin listeye Web ile kaydolma sayfası), veya özel bir konu içeren (örneğin: @adresse_suivi@?subject=subscribe) bir e-posta adresi olabilir:',
	'info_config_suivi_explication' => 'Bu sitenin gönderi listesi (mailing-list)’ne abone olabilirsiniz. O takdirde yayınlanması önerilen makale ve haber ilanları e-posta yoluyla elinize geçecektir. ',
	'info_confirmer_passe' => 'Yeni şifrenin teyid edilmesi :',
	'info_conflit_edition_avis_non_sauvegarde' => 'Dikkat, şu alanlar başka bir yerden değiştirildi. Sizin bu alanlardaki değişiklikleriniz kaydedilmedi.',
	'info_conflit_edition_differences' => 'Farklar :',
	'info_conflit_edition_version_enregistree' => 'Kayıtlı sürüm :',
	'info_conflit_edition_votre_version' => 'Sizin sürümünüz :',
	'info_connexion_base' => 'Veritabanına bağlanma denemesi',
	'info_connexion_base_donnee' => 'Veri tabanınıza bağlantı',
	'info_connexion_ldap_ok' => 'LDAP bağlantısı başarılı. Sonraki aşamaya geçebilirsiniz.',
	'info_connexion_mysql' => 'SQL bağlantınız',
	'info_connexion_ok' => 'Bağlantı başarılı. ',
	'info_contact' => 'İletişim',
	'info_contenu_articles' => 'Makalelerin içeriği',
	'info_contributions' => 'Katkılar', # RELIRE
	'info_creation_paragraphe' => 'Paragraf yaratmak için sadece boş bir satır bırakınız.',
	'info_creation_rubrique' => 'Makale yazmadan önce en az bir bölüm yaratmanız gerekir.',
	'info_creation_tables' => 'Veritabanı tablolarının yaratılması',
	'info_creer_base' => 'Yeni bir veritabanı <b>yaratılması</b> :',
	'info_dans_rubrique' => 'Bölümde :',
	'info_date_publication_anterieure' => 'Daha önceki yayınlanma tarihi :',
	'info_date_referencement' => 'BU SİTEYE ATIFTA BULUNULMA TARİHİ :',
	'info_derniere_etape' => 'Tamamlandı !',
	'info_descriptif' => 'Tanım :',
	'info_desinstaller_plugin' => 'verileri sil ve plugin’i pasif kıl',
	'info_discussion_cours' => 'Süren sohbetler',
	'info_ecrire_article' => 'Makale yazmadam önce en az bir bölüm yaratmanız gerekir.',
	'info_email_envoi' => 'Gönderi e-posta adresi (seçimlik)',
	'info_email_envoi_txt' => 'E-postaları göndermek için kullanılacak adresi burada belirtiniz (yoksa, gönderi adresi olarak alıcı adresi kullanılacaktır) :',
	'info_email_webmestre' => 'Webmaster e-posta adresi', # MODIF
	'info_envoi_email_automatique' => 'Otomatik e-posta gönderme',
	'info_envoyer_maintenant' => 'Şimdi gönder',
	'info_etape_suivante' => 'Bir sonraki aşamaya geç',
	'info_etape_suivante_1' => 'Bir sonraki aşamaya geçebilirsiniz',
	'info_etape_suivante_2' => 'Bir sonraki aşamaya geçebilirsiniz',
	'info_exceptions_proxy' => 'Vekil sunucu istisnaları', # RELIRE
	'info_exportation_base' => 'tabanın @archive@’e doğru ihracı',
	'info_facilite_suivi_activite' => 'Sitenin editör etkinliğinin izlenmesini kolaylaştırmak üzere,
                                   SPIP, e-posta ile, örneğin, yayınlama taleplerinin  ve makale
                                   onaylarının duyurusunu editörlerin bir gönderi listesine yollayabilir.', # MODIF
	'info_fichiers_authent' => ' « .htpasswd » tasdik dosyaları',
	'info_forums_abo_invites' => 'Siteniz abone yöntemiyle çalışan forumlar bulunduruyor ; dolayısıyla ziyaretçiler kamu sitesine kaydolmaya davet edilirler.', # MODIF
	'info_gauche_admin_tech' => '<b>Bu sayfa sadece site yetkililerinin erişimine izin verir. </b><p<Çeşitli teknik bakım işlevlerine erişim vermektedir. Bunlardan bazıları, Web sitesine bir FTP erişimi gerektiren özel bir tasdik sürecine yol açar.</p>',
	'info_gauche_auteurs' => 'Burada tüm site yazarlarını bulacaksınız. Statüleri simgelerinin rengi ile belirtilmiştir (yönetici = yeşil; yazı işleri = sarı).', # MODIF
	'info_gauche_auteurs_exterieurs' => 'Siteye erişimi olmayan dış yazarlar, mavi bir simgeyle belirtilmiştir ; silinen yazarlar ise gri bir simgeyle belirtilmiştir.',
	'info_gauche_messagerie' => 'Mesajlaşma sizin yazarlar ile ileti alışverişinde bulunmanızı, hatırlatmaları saklamanızı (kişisel amaçlı) veya özel alanın erişim sayfasına duyuru koymanızı sağlar (yöneticiyseniz).', # MODIF
	'info_gauche_statistiques_referers' => 'Bu sayfa atıflar listesini, yani sizin sitenize yönlendiren bağlar bulunduran sitelerin listesini sunar, ancak sadece dün ve bugün içindir ; bu liste her 24 saatte bir sıfırlanır.',
	'info_gauche_visiteurs_enregistres' => 'Burada sitenin kamu alanına kaydolan 
                                        ziyaretçileri bulacaksınız (abonelik yöntemiyle yönetilen forumlar).',
	'info_generation_miniatures_images' => 'Mevcut resimlerin minyatürlerinin üretilmesi',
	'info_gerer_trad_objets' => '@objets@ : çeviri bağlantıları yönet', # RELIRE
	'info_hebergeur_desactiver_envoi_email' => 'Bazı Hizmet bilgisayarları kendi sunucularından 
                                           otomatik e-posta gönderisini durduruyorlar. 
                                           Bu durumda SPIP’in şu işlevleri çalışmaz :',
	'info_hier' => 'Dün :',
	'info_identification_publique' => 'Kamu kimliğiniz ...',
	'info_image_process' => 'Lütfen, uygun resme tıklayarak en iyi ikon üretim yöntemini seçiniz. ',
	'info_image_process2' => 'Hiç resim çıkmıyorsa, sitenizi yayınlayan sunucu bu tür araçlar kullanmak için konfigüre edilmemiş demektir. Eğer bu işlevleri kullanmak istiyorsanız teknik yetkiliye başvurun ve «GD» ya da «Imagick» aksesuarlarını isteyin.',
	'info_images_auto' => 'Otomatik olarak hesaplanan resimler',
	'info_informations_personnelles' => 'Kişisel bilgiler',
	'info_inscription' => 'Kayıt tarihi', # RELIRE
	'info_inscription_automatique' => 'Yeni yazarların otomatik kaydı', # MODIF
	'info_jeu_caractere' => 'Sitedeki yazı tipi',
	'info_jours' => 'Günler',
	'info_laisser_champs_vides' => 'Bu alanları boş bırakınız.)',
	'info_langues' => 'Sitenin dilleri',
	'info_ldap_ok' => 'LDAP tasdiki kuruldu.',
	'info_lien_hypertexte' => 'Hipermetin bağı :',
	'info_liste_redacteurs_connectes' => 'Bağlanan yazarlar', # MODIF
	'info_login_existant' => 'Bu kullanıcı ismi zaten var.',
	'info_login_trop_court' => 'Kullanıcı ismi çok kısa.',
	'info_login_trop_court_car_pluriel' => 'Kullanıcı adı en az @nb@ karakter olmalıdır.', # RELIRE
	'info_logos' => 'Logolar',
	'info_maximum' => 'En fazla :',
	'info_meme_rubrique' => 'Aynı bölümde',
	'info_message_en_redaction' => 'Yazılmakta olan mesajlarınız',
	'info_message_technique' => 'Teknik ileti :',
	'info_messagerie_interne' => 'İç mesajlaşma',
	'info_mise_a_niveau_base' => 'SQL veri tabanınızın seviye yükseltmesi',
	'info_mise_a_niveau_base_2' => '{{Dikkat!}}  bu sitede bulunan SPIP
            dosyalarının {daha önceki}
            sürümünü yüklediniz:
            veritabanınız kaybolabilir ve siteniz işlemez hale gelebilir.
            {{SPIP dosyalarını tekrar kurunuz.}}',
	'info_modification_enregistree' => 'Değişiklikleriniz kaydedildi', # RELIRE
	'info_modifier_auteur' => 'Yazarı değiştir :',
	'info_modifier_rubrique' => 'Bölümü değiştir :',
	'info_modifier_titre' => 'Değiştir : @titre@',
	'info_mon_site_spip' => 'Benim SPIP sitem',
	'info_moyenne' => 'Ortalama :',
	'info_multi_cet_article' => 'Bu makalenin dili :',
	'info_multi_langues_choisies' => 'Lütfen aşağıda sitenizdeki yazarların kullanabileceği dilleri seçiniz.
    Sitenizde daha önce kullanılan (ve görüntülenen) diller iptal edilemez. ', # MODIF
	'info_multi_objets' => '@objets@ : dil menüsünü etkinleştir', # RELIRE
	'info_multi_secteurs' => 'Sadece kök dizinde yer alan bölümler için mi ?',
	'info_nb_articles' => '@nb@ makale', # RELIRE
	'info_nb_auteurs' => '@nb@ yazar', # RELIRE
	'info_nb_messages' => '@nb@ mesaj', # RELIRE
	'info_nb_mots_cles' => '@nb@ anahtar kelime', # RELIRE
	'info_nb_visiteurs' => '@nb@ ziyaretçi', # RELIRE
	'info_nom' => 'İsim',
	'info_nom_destinataire' => 'Alıcının ismi',
	'info_nom_site' => 'Sitenizin ismi',
	'info_nombre_articles' => '@nb_articles@ makale,',
	'info_nombre_rubriques' => '@nb_rubriques@ bölüm,',
	'info_nombre_sites' => '@nb_sites@ site,',
	'info_non_deplacer' => 'Yerini değiştirmeyin...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP düzenli olarak sitenin son yeniliklerini duyurabilir
     (yeni yayınlanmış makale ve kısa haberler).',
	'info_non_envoi_liste_nouveautes' => 'Yenilikler listesini gönderme',
	'info_non_modifiable' => 'Değiştirilemez',
	'info_non_suppression_mot_cle' => 'Bu anahtar sözcüğün silinmesini istemiyorum.',
	'info_notes' => 'Notlar',
	'info_nouvel_article' => 'Yeni makale',
	'info_nouvelle_traduction' => 'Yeni çeviri :',
	'info_numero_article' => 'MAKALE N° :',
	'info_obligatoire_02' => '(Zorunlu)', # MODIF
	'info_option_accepter_visiteurs' => 'Kamu sitesi ziyaretçilerinin kaydını kabul et', # MODIF
	'info_option_ne_pas_accepter_visiteurs' => 'Ziyaretçi kayıdını reddet', # MODIF
	'info_options_avancees' => 'GELİŞMİŞ SEÇENEKLER',
	'info_ou' => 'Veya ...',
	'info_page_interdite' => 'Yasaklanmış sayfa',
	'info_par_nom' => 'isme göre',
	'info_par_nombre_article' => 'makale sayısına göre',
	'info_par_statut' => 'duruma göre',
	'info_par_tri' => '’(@tri@ sıralamasına göre) ’',
	'info_passe_trop_court' => 'Şifre çok kısa.',
	'info_passe_trop_court_car_pluriel' => 'Şifre en az @nb@ karakter olmalıdır.', # RELIRE
	'info_passes_identiques' => 'İki şifre aynı değil.',
	'info_plus_cinq_car' => '5 karakterden fazla',
	'info_plus_cinq_car_2' => '(5 karakterden fazla)',
	'info_plus_trois_car' => '(3 karakterden fazla)',
	'info_popularite' => 'popülerlik : @popularite@ ; ziyaretler : @visites@',
	'info_post_scriptum' => ' Not :',
	'info_post_scriptum_2' => ' Not :',
	'info_pour' => ' Için',
	'info_preview_texte' => 'Siteyi en azından « önerildi » statüsüne sahip olan tüm makale ve haberler yayınlanmış gibi önizlemeye almak olanaklıdır. Bu olanak sadece yöneticilere mi, tüm yazarlara mı, açık olmalı yoksa hiç kimseye açık olmamalı mı ?', # MODIF
	'info_procedez_par_etape' => 'Aşama aşama ilerleyiniz',
	'info_procedure_maj_version' => 'Veritabanını yeni SPIP sürümüne uyarlamak için
              seviye yükseltme işlemi başlatılmalı.',
	'info_proxy_ok' => 'Vekil (Proxy) denemesi başarılı.',
	'info_ps' => 'Not :',
	'info_publier' => 'Yayınla',
	'info_publies' => 'Çevrimiçi yayınlanan makaleleriniz',
	'info_question_accepter_visiteurs' => 'Eğer sitenizin iskeleti özel alana erişimi olmayan ziyaretçilerin kaydını öngörüyorsa, aşağıdaki seçeneği çalıştırınız :', # MODIF
	'info_question_inscription_nouveaux_redacteurs' => 'Kamu sitesinden yeni editörlerin kaydolmasını kabul ediyor musunuz ?
    Eğer kabul ediyorsanız, ziyaretçiler otomatik
    bir form ile kaydolabilecek ve kendi makalelerini
    önermek üzere özel alana erişeceklerdir. 
<div class="notice">Kayıt aşamasında,    kullanıcılara,  özel siteye erişim şifresi veren bir otomatik
    e-posta gönderilir. Bazı Hizmet bilgisayarları kendi sunucularından
    e-posta yollanmasını durduruyorlar : bu durumda otomatik kayıt olanaksızdır.</div>', # MODIF
	'info_qui_edite' => '@nom_auteur_modif@ @date_diff@ dakika önce  bu içeriği üzerine çalıştı', # RELIRE
	'info_racine_site' => 'Sitenin kökü',
	'info_recharger_page' => 'Lütfen bu sayfayı az sonra tekrar yükleyiniz.',
	'info_recherche_auteur_zero' => ' "@cherche_auteur@" için hiç bir sonuç elde edilemedi.',
	'info_recommencer' => 'Lütfen baştan başlayınız.',
	'info_redacteur_1' => 'Editör',
	'info_redacteur_2' => 'Özel alana girişi olan (tavsiye edilen)',
	'info_redacteurs' => 'Editörler',
	'info_redaction_en_cours' => 'YAZIM AŞAMASINDA',
	'info_redirection' => 'Yönlendirme',
	'info_redirection_activee' => 'Yönlendirme etkindir.', # RELIRE
	'info_redirection_boucle' => 'Makaleyi kendisine yönlendirmeye çalışıyorsunuz.', # RELIRE
	'info_redirection_desactivee' => 'Yönlendirme silindi.', # RELIRE
	'info_refuses' => 'Reddedilen makaleleriniz',
	'info_reglage_ldap' => 'Seçenekler : <b>LDAP ithalinin ayarlanması.</b>',
	'info_renvoi_article' => '<b>Yönlendirme.</b> Bu makalenin bizi şu sayfaya yönlendirir:',
	'info_reserve_admin' => 'Bu adresi sadece yöneticiler değiştirebilir.', # MODIF
	'info_restreindre_rubrique' => 'Yönetimi bu bölümle sınırla:',
	'info_resultat_recherche' => 'Arama sonucu :',
	'info_rubriques' => 'Bölümler',
	'info_rubriques_02' => 'bölüm',
	'info_rubriques_trouvees' => 'Bulunan bölümler',
	'info_sans_titre' => 'Başlıksız',
	'info_selection_chemin_acces' => 'Rehbere erişim yolunu <b>seçiniz</b> :',
	'info_signatures' => 'İmzalar',
	'info_site' => 'Site ',
	'info_site_2' => 'Site :',
	'info_site_min' => 'Site ',
	'info_site_reference_2' => 'Atıfta bulunan site',
	'info_site_web' => 'WEB SiTESİ :', # MODIF
	'info_sites' => 'Siteler',
	'info_sites_lies_mot' => 'Bu anahtar sözcüğe bağlı atıfta bulunulan siteler',
	'info_sites_proxy' => 'Vekil kullan',
	'info_sites_trouves' => 'Bulunan siteler',
	'info_sous_titre' => 'Alt-başlık :',
	'info_statut_administrateur' => 'Yönetici', # MODIF
	'info_statut_auteur' => 'Bu yazarın statüsü :',
	'info_statut_auteur_a_confirmer' => 'Onaylanacak kayıt',
	'info_statut_auteur_autre' => 'Diğer statü :',
	'info_statut_redacteur' => 'Yazar',
	'info_statut_utilisateurs_1' => 'İthal edilen kullanıcıların varsayılan statüsü', # MODIF
	'info_statut_utilisateurs_2' => 'LDAP dizininde mevcut olan kişilere ilk defa bağlantı kurduklarında verilen statüyü seçiniz. Sonradan bu statüyü her bir yazar için tek tek değiştirebilirsiniz.', # MODIF
	'info_suivi_activite' => 'Yayın etkinliklerini izleme',
	'info_surtitre' => 'Üst başlık :',
	'info_syndication_integrale_1' => 'Siteniz paylaşım dosyaları öneriyor  (bkz « <a href="@url@">@titre@</a> »).',
	'info_syndication_integrale_2' => 'Makaleleri oldukları gibi mi iletmek isterseniz yoksa bir kaç yüz sözcüklük özetlerini mi ?',
	'info_table_prefix' => 'Aynı veritabanına bir çok site kuracaksanız veri tablolarının ismindeki ön-eki değiştirebilirsiniz : yalnız aksansız küçük harf kullanmalısınız.',
	'info_taille_maximale_images' => 'SPIP (milyon piksel cinsinden)işleyebileceği en büyük resim boyunu deneyecek.<br /> Bundan daha büyük resimler işlenmeyecek.',
	'info_taille_maximale_vignette' => 'Sistem tarafından üretilen en büyük ikon boyutu :',
	'info_terminer_installation' => 'Artık standart kurulum işlemini bitirebilirsiniz.',
	'info_texte' => 'Metin',
	'info_texte_explicatif' => 'Açıklama metni ',
	'info_texte_long' => '(Metin uzun : dolayısıyla onaylandıktan sonra bir araya getirilecek birkaç parça halinde görünüyor.)',
	'info_texte_message' => 'İletinizin metni :', # MODIF
	'info_texte_message_02' => 'İleti metni',
	'info_titre' => 'Başlık :',
	'info_total' => 'toplam :',
	'info_tous_articles_en_redaction' => 'Yazılmakta olan tüm makaleler',
	'info_tous_articles_presents' => 'Bu bölümde yayınlanan tüm makaleler',
	'info_tous_articles_refuses' => 'Reddedilen tüm makaleler', # RELIRE
	'info_tous_les' => 'her bir :',
	'info_tout_site' => 'Tüm siteyi',
	'info_tout_site2' => 'Makale bu dile çevrilmedi.',
	'info_tout_site3' => 'Makale bu dile çevrildi ancak sonradan atıfta bulunulan makalede değişiklikler yapıldı. Çeviri güncellenmeli.',
	'info_tout_site4' => 'Makale bu dile çevrildi ve çeviri güncel.',
	'info_tout_site5' => 'Makalenin orijinali.',
	'info_tout_site6' => '<b>Dikkat :</b>
      sadece orijinal makaleler görüntüleniyor.
 Orijinale bağlı çeviriler durumlarını belirten bir renkle belirtilmiştir :',
	'info_traductions' => 'Çevirmeler', # RELIRE
	'info_travail_colaboratif' => 'Makalelerde işbirliği',
	'info_un_article' => 'bir makale,',
	'info_un_site' => 'bir site,',
	'info_une_rubrique' => 'bir bölüm,',
	'info_une_rubrique_02' => '1 bölüm',
	'info_url' => 'URL :',
	'info_url_proxy' => 'Vekil sunucu URL', # RELIRE
	'info_url_site_pas_conforme' => 'Site URL geçersiz.', # RELIRE
	'info_url_test_proxy' => 'Site URL geçersiz.', # RELIRE
	'info_urlref' => 'Hipermetin bağı :',
	'info_utilisation_spip' => 'SPIP artık kullanılmaya hazırdır...',
	'info_visites_par_mois' => 'Ay olarak görüntüleme :',
	'info_visiteur_1' => 'Kamu sitesi',
	'info_visiteur_2' => 'ziyaretçisi',
	'info_visiteurs' => 'Ziyaretçiler',
	'info_visiteurs_02' => 'Kamu sitesi ziyaretçileri ',
	'info_webmestre_forces' => 'Webmasterler <tt>@file_options@</tt> dosyasında tanımlanır.', # MODIF
	'install_adresse_base_hebergeur' => 'Barındırma firması tarafından atanmış veritabanının adresi',
	'install_connect_ok' => 'Yeni veri tabanı @connect@ adı olara tanımlanmış.', # RELIRE
	'install_echec_annonce' => 'Kurulum büyük olasılıkla başarısız olacak veya site çalışmayacak...',
	'install_extension_mbstring' => 'SPIP belirtilen programla çalışamaz :',
	'install_extension_php_obligatoire' => 'SPIP için php uzantısı zorunludur :',
	'install_login_base_hebergeur' => 'Barındırma firması tarafından atanmış kullanıcı ismi',
	'install_nom_base_hebergeur' => 'Barındırma firması tarafından atanmış veritabanının ismi :',
	'install_pas_table' => 'Şu anda tablo içermeyen veri tabanı',
	'install_pass_base_hebergeur' => 'Barındırma firması tarafından atanmış bağlantı şifresi',
	'install_php_version' => '@version@ PHP sürümü yetersiz (minimum = @minimum@)',
	'install_select_langue' => 'Bir dil seçiniz, sonra « bir sonraki » düğmesini tıklayıp yükleme işlemini başlatınız.',
	'install_select_type_db' => 'Veri tabanının tipini belirtiniz :',
	'install_select_type_mysql' => 'MySQL',
	'install_select_type_pg' => 'PostgreSQL',
	'install_select_type_sqlite2' => 'SQLite 2',
	'install_select_type_sqlite3' => 'SQLite 3',
	'install_serveur_hebergeur' => 'Servis sağlayıcı tarafından sağlanan veri tabanı sunucusu',
	'install_table_prefix_hebergeur' => 'Barındırma firması tarafından atanmış tablo ön eki',
	'install_tables_base' => 'Veri tabanı tabloları',
	'install_types_db_connus' => 'SPIP <b>MySQL</b> (en yaygın),  ve <b>SQLite</b> kullanmayı bilir.',
	'install_types_db_connus_avertissement' => '<b>PostgresSQL desteği</b> da deneysel olarak verilmiştir', # RELIRE
	'instituer_erreur_statut_a_change' => 'Durum zaten değiştirildi', # RELIRE
	'intem_redacteur' => 'Yazar',
	'intitule_licence' => 'Lisans',
	'item_accepter_inscriptions' => 'Kayıtları kabul et',
	'item_activer_messages_avertissement' => 'Uyarı iletilerini etkinleştir',
	'item_administrateur_2' => 'yönetici', # MODIF
	'item_afficher_calendrier' => 'Takvimde görüntüle',
	'item_autoriser_syndication_integrale' => 'Makaleleri paylaşım dosyalarında oldukları gibi yayınla',
	'item_choix_administrateurs' => 'Yöneticiler ', # MODIF
	'item_choix_generation_miniature' => 'Resimlerin minyatürlerini otomatik olarak üret',
	'item_choix_non_generation_miniature' => 'Resimlerin minyatürlerini otomatik olarak üretme',
	'item_choix_redacteurs' => 'Yazarlar',
	'item_choix_visiteurs' => 'Kamu sitesi ziyaretçileri',
	'item_creer_fichiers_authent' => '.htpasswd dosyalarını yarat',
	'item_login' => 'Kullanıcı ismi',
	'item_messagerie_agenda' => 'Mesajlaşmayı ve ajandayı aktive et',
	'item_mots_cles_association_articles' => 'Makalelere ',
	'item_mots_cles_association_rubriques' => 'Bölümlere ',
	'item_mots_cles_association_sites' => 'atıfta bulunulan ya da paylaşımlı sitelere',
	'item_non' => 'Hayır ',
	'item_non_accepter_inscriptions' => 'Kayıtları reddet',
	'item_non_activer_messages_avertissement' => 'Uyarı iletisi yok',
	'item_non_afficher_calendrier' => 'Takvimde gösterme',
	'item_non_autoriser_syndication_integrale' => 'Sadece özet yayınla',
	'item_non_creer_fichiers_authent' => 'Bu dosyaların yaratma',
	'item_non_messagerie_agenda' => 'Mesajlaşmayı ve ajandayı dezaktive et',
	'item_non_publier_articles' => 'Makaleleri yayın tarihinden önce yayınlama',
	'item_nouvel_auteur' => 'Yeni yazar ',
	'item_nouvelle_rubrique' => 'Yeni bölüm ',
	'item_oui' => 'Evet  ',
	'item_publier_articles' => 'Makaleleri yayın tarihlerine bakmadan yayınla',
	'item_reponse_article' => 'Makaleye yanıt ',
	'item_visiteur' => 'Ziyaretçi ',

	// J
	'jour_non_connu_nc' => 'Bilinmeyen ',

	// L
	'label_bando_outils' => 'Araç çubuğu', # RELIRE
	'label_bando_outils_afficher' => 'Araçları göster', # RELIRE
	'label_bando_outils_masquer' => 'Araçları gizle', # RELIRE
	'label_nom_fichier_connect' => 'Bu sunucunun adını girin', # RELIRE
	'label_slogan_site' => '
Site sloganı', # RELIRE
	'label_texte_et_icones_navigation' => 'Navigasyon menüsü', # RELIRE
	'lien_ajouter_auteur' => 'Bu yazarın ekle',
	'lien_ajouter_une_rubrique' => 'Bu bölüm ekle', # RELIRE
	'lien_email' => 'e-posta ',
	'lien_nom_site' => 'SİTENİN ADI : ',
	'lien_rapide_contenu' => 'İçeriğe git', # RELIRE
	'lien_rapide_navigation' => 'Navigasyona git', # RELIRE
	'lien_rapide_recherche' => 'Navigasyon’a git', # RELIRE
	'lien_retirer_auteur' => 'Yazarı sil',
	'lien_retirer_rubrique' => 'Bölümü çıkar', # RELIRE
	'lien_retirer_tous_auteurs' => 'Tüm yazarlar çıkar', # RELIRE
	'lien_retirer_toutes_rubriques' => 'Tüm bölümler çıkar', # RELIRE
	'lien_site' => 'site',
	'lien_tout_decocher' => 'Tüm işarelteri kaldır', # RELIRE
	'lien_tout_deplier' => 'Tümünün katlarını aç',
	'lien_tout_replier' => 'Tümünü geri katla',
	'lien_tout_supprimer' => 'Hepsini sil',
	'lien_trier_nom' => 'İsme göre sırala',
	'lien_trier_nombre_articles' => 'Makale sayısına göre sırala',
	'lien_trier_statut' => 'Duruma göre sırala',
	'lien_voir_en_ligne' => 'ÇEVRİMİÇİ GÖSTER :',
	'logo_article' => 'Makale logosu',
	'logo_auteur' => 'Yazar logosu',
	'logo_rubrique' => 'Bölüm logosu',
	'logo_site' => 'Siste logosu',
	'logo_standard_rubrique' => 'Standart bölüm logosu',
	'logo_survol' => 'Üzerinden geçme logosu', # RELIRE

	// M
	'menu_aide_installation_choix_base' => 'Veritabanınızın seçimi',
	'module_fichier_langue' => 'Dil dosyası ',
	'module_raccourci' => 'Kısayol',
	'module_texte_affiche' => 'Gösterilen metin',
	'module_texte_explicatif' => 'Kamu sitenizin şablonlarına şu kestirmeleri ekleyebilirsiniz. Dil  dosyası çevirisi bulunan çeşitli dillere otomatik olarak çevrileceklerdir.',
	'module_texte_traduction' => '« @module@ » dil dosyasının bulunduğu yer :',
	'mois_non_connu' => 'Bilinmiyor ',

	// N
	'nouvelle_version_spip' => 'Güncelleştirme SPIP @version@ mevcuttur', # RELIRE
	'nouvelle_version_spip_majeure' => 'SPIP yeni bir sürümü mecvuttur  @version@ ', # RELIRE

	// O
	'onglet_contenu' => 'İçerik',
	'onglet_declarer_une_autre_base' => 'Başka bir veri tabanı bildirin',
	'onglet_discuter' => 'Tartışma',
	'onglet_interactivite' => 'Etkileşimlilik',
	'onglet_proprietes' => 'Özellikler',
	'onglet_repartition_actuelle' => 'Şu anda  ',
	'onglet_sous_rubriques' => 'Alt-başlıklar',

	// P
	'page_pas_proxy' => 'Bu sayfa velilden (proxy) geçmemeli',
	'pas_de_proxy_pour' => 'Gerekirse, bu vekilin uygulanmayacağı  makineleri veya alanları belirtiniz (örneğin : @ornek@)',
	'phpinfo' => 'PHP ayarları', # RELIRE
	'plugin_charge_paquet' => '@name@ paketinin yüklenmesi',
	'plugin_charger' => 'İndir', # RELIRE
	'plugin_erreur_charger' => 'hata : @zip@ yüklenmesi olanaksız',
	'plugin_erreur_droit1' => '<code>@dest@</code> dizini yazmak için izinli değil.',
	'plugin_erreur_droit2' => 'Bu dizindeki hakları kontrol ediniz (ve hata durumunda oluşturunuz) veya dosyaları FTP ile kurunuz.',
	'plugin_erreur_zip' => 'pclzip hatası : hata @status@',
	'plugin_etat_developpement' => 'geliştirme aşamasında',
	'plugin_etat_experimental' => 'deneysel',
	'plugin_etat_stable' => 'durgun ("stable")',
	'plugin_etat_test' => 'test aşamasında',
	'plugin_impossible_activer' => '@plugin@ plugin’ini aktive etmek olanaksız',
	'plugin_info_automatique1' => 'Eklentilerin otomatik yüklenmesini istiyorsanız, lütfen :',
	'plugin_info_automatique1_lib' => 'Bu kütüphanenin otomatik olarak yüklenmesini izin vermek istiyorsanız, lütfen:', # RELIRE
	'plugin_info_automatique2' => '<code>@rep@</code> isimli bir dizin oluşturun ;',
	'plugin_info_automatique3' => 'sunucunun bu dizine yazma hakkı olduğunu kontrol ediniz',
	'plugin_info_automatique_creer' => 'sitenin kök dizinini oluşturma',
	'plugin_info_automatique_exemples' => 'örnekler :',
	'plugin_info_automatique_ftp' => 'Eklentileri FTP ile <tt>@rep@</tt> dizinine yükleyebilirsiniz',
	'plugin_info_automatique_lib' => 'Bazı eklentiler  demandent aussi à pouvoir <code>lib/</code> dizinine dosya indirme iznini de gerektirirler, aksi halde bu dizini sitenin kök dizininde oluştururlar.',
	'plugin_info_automatique_liste' => 'Eklenti listeleriniz :',
	'plugin_info_automatique_liste_officielle' => 'resmî eklentiler',
	'plugin_info_automatique_liste_update' => 'Listeleri güncelle',
	'plugin_info_automatique_ou' => 'veya...',
	'plugin_info_automatique_select' => 'Aşağıdan bir eklenti seçiniz : SPIP o eklentiyi indirecek ve <code>@rep@</code> dizinine kuracaktır ; eğer bu eklenti zaten kurulu ise güncellenecektir.',
	'plugin_info_credit' => 'Kredi', # RELIRE
	'plugin_info_erreur_xml' => 'Bu plugin beyanı yanlış', # RELIRE
	'plugin_info_install_ok' => 'Kurulum başarılı', # RELIRE
	'plugin_info_necessite' => 'İstiyor :', # RELIRE
	'plugin_info_telecharger' => '@url@ adresinden indirmeye ve @rep@ dizinine yüklemeye',
	'plugin_librairies_installees' => 'Kurulu kütüphaneler',
	'plugin_necessite_lib' => 'Bu eklenti @lib@ kütüphanesini gerektirir',
	'plugin_necessite_plugin' => '@plugin@ plugin’inin en az @version@ sürümünü gerektirir.',
	'plugin_necessite_plugin_sans_version' => 'Plugin @plugin@ isteniyor', # RELIRE
	'plugin_necessite_spip' => 'SPIP’in en az @version@ sürümünü gerektirir.',
	'plugin_source' => 'kaynak: ',
	'plugin_titre_automatique' => 'Otomatik kurulum',
	'plugin_titre_automatique_ajouter' => 'Eklenti ekleyiniz',
	'plugin_titre_installation' => 'Plugin @plugin@ yüklemesi', # RELIRE
	'plugin_titre_modifier' => 'Pluginlerim', # RELIRE
	'plugin_utilise_plugin' => 'plugin @plugin@  @version@ kullanıyor', # MODIF
	'plugin_zip_active' => 'Aktive etmek için devam ediniz',
	'plugin_zip_adresse' => 'aşağıda indirilecek eklentiye ait zip dosyasının adresini veya bir çok eklentinin adres listesini belirtiniz.',
	'plugin_zip_adresse_champ' => 'Eklentinin veya listenin adresi ',
	'plugin_zip_content' => 'Şu dosyaları içerir (@taille@). <br />Bu yüklenebilir dosyalar şu dizinde bulunuyor :<code>@rep@</code>',
	'plugin_zip_installe_finie' => '@zip@ dosyası açıldı ve yüklendi.',
	'plugin_zip_installe_rep_finie' => '@zip@ dosyası açıldı ve @rep@ dizinine yüklendi.',
	'plugin_zip_installer' => 'Şimdi yükleyebilirsiniz.',
	'plugin_zip_telecharge' => '@zip@ dosyası bilgisayara indirildi',
	'plugins_actif_aucun' => 'Hiç etkin plugini yok', # RELIRE
	'plugins_actif_un' => 'Bir tane plugin etkin.', # RELIRE
	'plugins_actifs' => '@count@ eklenti etkinleştirildi.',
	'plugins_compte' => '@count@ eklenti',
	'plugins_disponible_un' => 'Bİr tane plugin mecvuttur.', # RELIRE
	'plugins_disponibles' => '@count@ eklenti kullanılabilir durumda.',
	'plugins_erreur' => 'Eklentilerde hata var : @plugins@',
	'plugins_liste' => 'Plugin listesi',
	'plugins_liste_dist' => 'Kilitli pluginler', # RELIRE
	'plugins_recents' => 'Son pluginleri.', # RELIRE
	'plugins_tous_liste' => 'Hepsi', # RELIRE
	'plugins_vue_hierarchie' => 'Hiyerarşi',
	'plugins_vue_liste' => 'Liste',
	'protocole_ldap' => 'Protokol sürümü :',

	// Q
	'queue_info_purger' => 'Bekleyen tüm işleri silip periyodik işler listesi sıfırlayabilirsiniz', # MODIF
	'queue_next_job_in_nb_sec' => 'Sonraki iş @nb@ s ’den sonra', # MODIF
	'queue_no_job_in_queue' => 'Bekleyen iş yok', # MODIF
	'queue_one_job_in_queue' => '1 bekleyen iş var', # MODIF
	'queue_purger_queue' => 'İş listesini sıfırla', # MODIF
	'queue_titre' => 'İş listesi', # MODIF

	// R
	'repertoire_plugins' => 'Dizin :',
	'required' => '[Zorunlu]', # MODIF

	// S
	'sans_heure' => 'saatsiz',
	'statut_admin_restreint' => 'sınırlı yönetici',
	'statut_webmestre' => 'webmaster', # RELIRE

	// T
	'taille_cache_image' => 'SPIP tarafından otomatik olarak hesaplanan resimler (doküman ikonları, grafik olarak gösterilen başlıklar, TeX biçimindeki matematik işlevler...) @dir@ dizininde toplam @taille@ yer tutuyor.',
	'taille_cache_moins_de' => 'Önbellek boyutu @octets@ altında.', # RELIRE
	'taille_cache_octets' => 'Önbelleğin ölçüsü şu anda @octets@ dir.',
	'taille_cache_vide' => 'Ön bellek boş.',
	'taille_repertoire_cache' => 'Ön bellek dizininin boyutu',
	'text_article_propose_publication' => 'Yayın için önerilen makale. ',
	'texte_acces_ldap_anonyme_1' => 'Bazı LDAP sunucular hiç bir anonim erişimi kabul etmiyorlar. Bu durumda,  bir başlangıç erişim tanımlayıcısı belirtmek gerekir ki sonra dizinde bilgi aranabilsin. Ancak, bir çok durumda, şu alanlar boş bırakılabilir:',
	'texte_admin_effacer_01' => 'Bu komut veritabanının,
  yazarlar ve yönetici erişimleri dahil, <i>tüm</i> içeriğini siler.
  Bu komuttan sonra, yeni bir veritabanı ve bir yönetici 
  erişimi yaratmak üzere SPIP’i 
  yeniden yüklemelisiniz. ', # MODIF
	'texte_adresse_annuaire_1' => '(Eğer dizininiz bu Web sitesi ile aynı makinaya yüklenmiş ise, muhtemelen bir yerel hizmet bilgisayarı «localhost» sözkonusudur.)',
	'texte_ajout_auteur' => 'Makaleye şu yazar eklendi :',
	'texte_annuaire_ldap_1' => 'Eğer bir (LDAP) dizinine erişiminiz varsa, onu SPIP’e otomatik olarak kullanıcı ithal etmek için  kullanabilirsiniz. ', # MODIF
	'texte_article_statut' => 'Bu makale :',
	'texte_article_virtuel' => 'Sanal makale',
	'texte_article_virtuel_reference' => '<b>Sanal makale :</b> SPIP sitenizde atıfta bulunulan ancak başka bir URL’ye yönlendirilmiş bir makaledir. Yeniden yönlendirmeyi iptâl etmek için yukarıdaki URL’yi siliniz.',
	'texte_aucun_resultat_auteur' => '"@cherche_auteur@" için hiçbir sonuç yok.',
	'texte_auteur_messagerie' => 'Bu site size bağlı olan yazarların listesini sürekli olarak belirtebilir, bu da sizin doğrudan ileti alışverişinde bulunmanızı sağlar.  Bu listede görünmemeyi seçebilirsiniz (bu durumda diğer kullanıcılara « görünmez »sinizdir).', # MODIF
	'texte_auteurs' => 'YAZARLAR',
	'texte_choix_base_1' => 'Veritabanınızı seçiniz :',
	'texte_choix_base_2' => 'SQL sunucusu bir çok veritabanı içeriyor.',
	'texte_choix_base_3' => 'Aşağıda servis sağlayıcınız tarafından size ayrılmış olanı <b>seçiniz</b>.',
	'texte_choix_table_prefix' => 'Tablo ön-ekleri :',
	'texte_compte_element' => '@count@ eleman',
	'texte_compte_elements' => '@count@ eleman',
	'texte_conflit_edition_correction' => 'Lütfen aşağıdaki 2 metin arasındaki farkları kontrol edin ; değişikliklerinizi kopyalayıp devam da edebilirsiniz.',
	'texte_connexion_mysql' => 'Servis sağlayıcınız tarafından size verilen bilgilere bakınız : orada size önerilen veri tabanı sunucusunu ve bu sunucuya bağlanmak için gereken bilgileri bulacaksınız. ',
	'texte_contenu_article' => '(Birkaç sözcükte makalenin içeriği) ',
	'texte_contenu_articles' => 'Siteniz için benimsenen yerleşim planı uyarınca,
              makalelerin bazı elemanlarının kullanılmamasına karar verebilirsiniz.
              Hangi unsurların müsait olduğunu belirtmek için aşağıdaki listeyi kullanınız. ',
	'texte_crash_base' => 'Eğer veritabanınız bozulduysa,
              otomatik tamiri deneyebilirsiniz. ',
	'texte_creer_rubrique' => 'Makale yazabilmek için önce bir bölüm yaratmanız gerekmektedir.',
	'texte_date_creation_article' => 'MAKALENİN YAYIN TARİHİ :',
	'texte_date_creation_objet' => 'Oluşturulma tarihi :', # on ajoute le ":" RELIRE
	'texte_date_publication_anterieure' => 'Bir önceki düzeltme tarihi :',
	'texte_date_publication_anterieure_nonaffichee' => 'Yayın tarihini görüntüleme',
	'texte_date_publication_article' => 'ÇEVRİMİÇİ YAYINLANMA TARİHİ:',
	'texte_date_publication_objet' => 'Online yayınlama tarihi :', # RELIRE
	'texte_descriptif_rapide' => 'Hızlı tanım',
	'texte_effacer_base' => 'SPIP veritabanını sil',
	'texte_effacer_statistiques' => 'İstatistikleri sil',
	'texte_en_cours_validation' => 'Aşağıdaki makale ve kısa haberler yayın için önerilmiştir. ',
	'texte_enrichir_mise_a_jour' => 'Metninizin sayfa düzenini « tipografi kısaltmaları » kullanarak zenginleştirebilirsiniz.',
	'texte_fichier_authent' => '<b>SPIP’in, <tt>.htpasswd</tt> ve <tt>.htpasswd-admin</tt> özel dosyalarını  @dossier@ dizininde yaratması gerekir mi?</b> 
<p>Bu dosyalar sizin, sitenizin başka yerlerine sadece yazar ve yöneticilerin erişmesini sınırlamanızı sağlayabilir (örneğin, dışsal istatistik programı).</p>
<p> Bunun bir yararı olmadığını düşünüyorsanız bu seçeneği varsayılan değerinde bırakabilirsiniz (dosya yaratma işlemi yapılmaz).</p>', # MODIF
	'texte_informations_personnelles_1' => 'Sistem şimdi size kişiselleştirilmiş bir erişim (hesap) yaratacaktır.',
	'texte_informations_personnelles_2' => '(Not : eğer yeniden kurulum sözkonusu ise ve erişiminiz halen çalışıyorsa, yapabileceğiniz :',
	'texte_introductif_article' => '(Makalenin giriş metni.)',
	'texte_jeu_caractere' => 'Sitenizde evrensel alfabe (<tt>utf-8</tt>) kullanmanız önerilir: bu alfabe metinlerin tüm dillerde görüntülenmesine olanak tanır ve  modern web tarayıcılarında hiç sorun yaratmaz.',
	'texte_jeu_caractere_3' => 'Sitenizin şu anda kurulu olan karakter seti :',
	'texte_jeu_caractere_4' => 'Eğer bu verilerinize uymazsa (örneğin bir veritabanı kurtarma işleminden sonra)  veya <em>siteyi yeni kuruyorsanız</em> ve başka bir karakter setiyle devam etmek istiyorsanız bunu belirtmeyi unutmayınız :',
	'texte_login_ldap_1' => '(Ya anonim bir erişim için boş bırakınız ya da tüm yolu belirtiniz, örneğin; « uid=dupont, ou=users, dc=mon-domaine, dc=com ».)',
	'texte_login_precaution' => 'Dikkat ! Bu şu anki bağlantı için kullanılan kullanıcı ismidir.
 Bu formu dikkatli kullanınız...',
	'texte_messagerie_agenda' => 'Mesajlaşma, site yazarlarına özel alanda kendi aralarında direkt olarak haberleşme olnağı tanır. Mesajlaşma bir ajandaya bağlıdır.', # MODIF
	'texte_mise_a_niveau_base_1' => 'SPIP dosyalarını güncelleştirmiş bulunuyorsunuz. Şimdi sitenin veritabanını aynı seviyeye yükseltmeniz gerekir.',
	'texte_modifier_article' => 'Makaleyi değiştir :',
	'texte_multilinguisme' => 'Eğer karmaşık gezintili, bir kaç dilde makaleler yönetmek istiyorsanız makalelere ve/veya bölümlere sitenizin düzenine göre bir dil seçeneği mönüsü ekleyebilirsiniz.',
	'texte_multilinguisme_trad' => 'Ayrıca, bir makalenin çeşitli çevirileri arasında bir bağlantı yönetme sistemi de çalıştırabilirsiniz. ',
	'texte_non_compresse' => 'Sıkıştırılmamış (sunucunuz bu özniteliği taşıyamıyor). ',
	'texte_nouvelle_version_spip_1' => 'SPIP’in yeni bir sürümünü yüklediniz.',
	'texte_nouvelle_version_spip_2' => 'Bu yeni uyarlama alışılana göre daha eksiksiz bir güncelleştirme gerektirir. Eğer siz bu sitenin webmaster iseniz lütfen @connect@  dosyasını ecrire dizininden siliniz ve veritabanına bağlantı parametrelerinizi güncelleştirmek amacıyla yüklemeyi tekrar yapınız. <p>(Not : bağlantı parametrelerinizi unuttuysanız, silmeden önce @connect@ dosyasına bir göz atınız...) </p>',
	'texte_operation_echec' => 'Bir önceki sayfaya geri dönüp başka bir veri tabanı seçiniz ya da yeni bir tane yaratınız. Ana bilgisayarınız tarafından verilen bilgilerden emin olunuz. ',
	'texte_plus_trois_car' => '3 karakterden fazla',
	'texte_plusieurs_articles' => '"@cherche_auteur@" için bir kaç yazar bulundu : ',
	'texte_port_annuaire' => '(Genelde, varsayılan değer uygundur.) ',
	'texte_presente_plugin' => 'Bu sayfa sitedeki plugin’leri listeler. Gerekli plugin’leri uygun kutucukları işaretleyerek etkinleştirebilirsiniz.',
	'texte_proposer_publication' => 'Makaleniz bittiğinde, yayınlanmasını önerebilirsiniz. ',
	'texte_proxy' => 'Bazı durumlarda (intranet, korumalı ağlar...), referans verilen sitelere ulaşmak için bir <i>HTTP vekili</i> kullanmak gerekebilir. Başarısızlık durumunda, adresini aşağıya @proxy_en_cours@. (http://proxy:8080) biçiminde belirtiniz. Genelde bu kutu boş bırakılır.',
	'texte_publication_articles_post_dates' => 'Yayınlanması ileri bir tarihe saptanan makaleler karşısında SPIP ne gibi bir tavır almalı ?',
	'texte_rappel_selection_champs' => '[Bu alanı doğru olarak seçmeyi unutmayınız.] ',
	'texte_recalcul_page' => 'Sadece bir tek sayfayı yenilemek istiyorsanız, daha ziyade kamu sitesinden geçiniz ve orada « yenileme » düğmesini seçiniz.',
	'texte_recuperer_base' => 'Veritabanını tamir et',
	'texte_reference_mais_redirige' => 'SPIP sitenizde atıfta bulunulan ve başka bir URL’ye yönlendirilmiş makale.',
	'texte_requetes_echouent' => '<b>Bazı SQL talepleri sistematik olarak ve görünürde bir neden olmaksızın başarısız oluyorsa bunun nedeni veri tabanının kendisi olabilir.</b> <p>
SQL’in, kazayla zarar gören tablolarını onarma yeteneği vardır. Burada bu onarımı deneyebilirsiniz ; başarısızlık durumunda, görüntünün bir kopyasını saklayınız, belki orada aksayan şeylerin ipuçlarını bulabilirsiniz... Eğer sorun devam ederse servis sağlayıcınızla temasa geçiniz.</p>',
	'texte_selection_langue_principale' => 'Aşağıda sitenin « başlıca dil » ini seçebilirsiniz. Bu seçim, sizin makalelerinizi seçilen dilde yazmanızı gerektirmez, buna karşılık :
<ul><li> kamu sitesindeki tarihlerin varsayılan formatını ;</li>
<li> SPIP’in metinler için kullanacağı tipografi motorunun cinsini ;</li>
<li> kamu sitesinin formlarında kullanılan dili ;</li>
<li> özel alanda varsayılan dili belirlemeye yarar.</li></ul>',
	'texte_sous_titre' => 'Alt-başlık',
	'texte_statistiques_visites' => '(koyu çizgiler : pazar / koyu eğriler : ortalamanın gelişimi)',
	'texte_statut_attente_validation' => 'Onay bekliyor',
	'texte_statut_publies' => 'Yayınlandı',
	'texte_statut_refuses' => 'Reddedildi',
	'texte_suppression_fichiers' => 'Bu komutu SPIP önbelleğinde bulunan tüm dosyaları yok etmek için kullanınız. Örneğin grafiklerde ya da site yapısında önemli değişiklikler yaptıysanız tüm sayfaları yeniden oluşturulmaya zorlamanızı sağlar.',
	'texte_sur_titre' => 'Üst başlık ',
	'texte_table_ok' => ': bu tablo tamam.',
	'texte_tentative_recuperation' => 'Tamir denemesi',
	'texte_tenter_reparation' => 'Veritabanının tamirini dene',
	'texte_test_proxy' => 'Bu vekili denemek için buraya test etmek istediğiniz bir Web sitesinin adresini belirtiniz. ',
	'texte_titre_02' => 'Başlık :',
	'texte_titre_obligatoire' => '<b>Başlık</b> [Zorunlu]',
	'texte_travail_article' => '@nom_auteur_modif@ bu makale üzerinde @date_diff@ dakika önce çalıştı',
	'texte_travail_collaboratif' => 'Bir kaç yazarın aynı makalede çalışıyor olması sıkça rastlansa da, sistem eşzamanlı değişiklikleri önlemek amacıyla yeni « açılmış » olan makaleleri görüntüleyebilir.  Bu seçenek geçici uyarı iletilerinin görüntülenmesine engel olmak üzere  başlangıçta engellenmiştir.', # MODIF
	'texte_vide' => 'Boş ',
	'texte_vider_cache' => 'Önbelleği boşalt',
	'titre_admin_tech' => 'Teknik bakım ',
	'titre_ajouter_un_auteur' => 'Yazar ekle', # RELIRE
	'titre_ajouter_un_mot' => 'Anahtar kelime ekle', # RELIRE
	'titre_cadre_afficher_article' => 'Makaleleri göster',
	'titre_cadre_afficher_traductions' => 'Aşağıdaki dillerin çevirilerinin durumunu göster :',
	'titre_cadre_ajouter_auteur' => 'BİR YAZAR EKLE :',
	'titre_cadre_interieur_rubrique' => 'Bölüm içinde',
	'titre_cadre_numero_auteur' => 'YAZAR NO',
	'titre_cadre_numero_objet' => '@objet@ NUMARA :', # RELIRE
	'titre_cadre_signature_obligatoire' => '<b>İmza</b> [Zorunlu]<br />',
	'titre_config_contenu_notifications' => 'Notlama',
	'titre_config_contenu_prive' => 'Özel alanda',
	'titre_config_contenu_public' => 'Kamusal sitede',
	'titre_config_fonctions' => 'Site konfigürasyonu',
	'titre_config_langage' => 'Dil ayarları', # RELIRE
	'titre_configuration' => 'Site konfigürasyonu',
	'titre_configurer_preferences' => 'Tercihlerinizi ayarları', # RELIRE
	'titre_conflit_edition' => 'Düzenleme esnasında çakışma',
	'titre_connexion_ldap' => 'Seçenekler : <b>LDAP bağlantılarınız</b>',
	'titre_groupe_mots' => 'SÖZCÜK GRUBU:',
	'titre_identite_site' => 'Site kimliği', # RELIRE
	'titre_langue_article' => 'Makalenin dili',
	'titre_langue_rubrique' => 'Bölümün dili',
	'titre_langue_trad_article' => 'MAKALENİN DİLİ VE ÇEVİRİLERİ ',
	'titre_les_articles' => 'MAKALELER',
	'titre_messagerie_agenda' => 'Mesajlaşma ve Ajanda',
	'titre_naviguer_dans_le_site' => 'Sitede gezin...',
	'titre_nouvelle_rubrique' => 'Yeni bölüm',
	'titre_numero_rubrique' => 'BÖLÜM NO :',
	'titre_page_articles_edit' => 'Değiştir : @titre@',
	'titre_page_articles_page' => 'Makaleler  ',
	'titre_page_articles_tous' => 'Tüm site',
	'titre_page_calendrier' => 'Takvim @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'Site konfigürasyonu',
	'titre_page_delete_all' => 'tamamen ve geri alınamaz biçimde silinmesi',
	'titre_page_recherche' => 'Arama sonuçları  @recherche@ ',
	'titre_page_statistiques_referers' => 'İstatistikler (giriş bağları)',
	'titre_page_upgrade' => 'SPIP seviyesinin yükseltilmesi ',
	'titre_publication_articles_post_dates' => 'İleri tarihli makalelerin yayınlanması ',
	'titre_reparation' => 'Onarım',
	'titre_suivi_petition' => 'Dilekçelerin izlenmesi',
	'tls_ldap' => 'Taşıma Katmanı Güvenliği (TLS) :',
	'trad_article_traduction' => 'Bu makalenin tüm sürümleri :',
	'trad_delier' => 'Bu makaleyi artık şu çevirilere bağlama', # MODIF
	'trad_lier' => 'Bu makale şu nolu makalenin çevirisidir :',
	'trad_new' => 'Bu makalenin yeni bir çevirisini yaz', # MODIF

	// U
	'utf8_convert_erreur_orig' => 'Hata : @charset@ karakter seti desteklenmiyor.',

	// V
	'version' => 'Sürüm :',
];
